#!/bin/bash

# FUNCTIONS
function processdisplay() {
	echo ""
	echo "===> "$1
	echo ""
	sleep 3
}

function feedback() {
	echo ""
	echo "********************"
	echo "** "
	
	for arg; do
  		echo "** $arg"
	done
	
	echo "** "
	echo "********************"
	echo ""
	read -p "===> Press [enter] to continue"
}

##
# Ask to proceed or exit
inquire(){
    echo -n "Shall we continue? (yes, skip, quit) [y]/[n]: "
    read REPLY
    if [ -z $REPLY ]; then REPLY="y"; fi
    if [ $REPLY = "y" ]; then
        PROCEED=y
    fi
    if [ $REPLY = "n" ]; then
        PROCEED=n
    fi
}

##
# Make sure we're root
if [ "$UID" != "0" ]; then
    echo "Error: You must be root"
    exit 1
fi

# Bring in our config file
source ./user.config

# VARS THAT SHOULD NOT BE CHANGED
# Config is done in user.config
declare -rx MAINFLDR="$INSTALLPATH/main"

# Display title
processdisplay "STARTING COD5-PLUS CENTOS/WINE INSTALLER <==="

# Be sure the system is up to date
processdisplay "UPDATING ALL SYSTEM PACKAGES"
yum -y update

# Install screen command
processdisplay "INSTALLING SCREEN COMMAND"
yum -y install screen

# Install wine dependencies
processdisplay "INSTALLING WINE DEPENDENCIES"
yum -y install lcms mesa-libGLU alsa-lib gphoto2 audiofile esound xorg-x11-apps

# Creating the server directory
processdisplay "CREATING DIRECTORY STRUCTURE"
mkdir -p $MAINFLDR
mkdir -p $DOWNLOADS

# Get the dedicated server files
processdisplay "GETTING SERVER FILES"
cd $INSTALLPATH
wget $SRVFILES1
cd $MAINFLDR
wget $SRVFILES2
cd $MAINFLDR
wget $SRVFILES3
cd $INSTALLPATH
wget $SRVPATCHFILES1

# Get the wine files
processdisplay "GETTING WINE FILES"
cd $DOWNLOADS
wget $WINE1
wget $WINE2
wget $WINE3
wget $WINE4
wget $WINE5
wget $WINE6
wget $WINE7
wget $WINE8
wget $WINE9


# Install wine
processdisplay "INSTALLING WINE"
rpm -Uvh wine-*1.1.10*

# Unzip the files
processdisplay "UNZIPPING SERVER FILES"
cd $INSTALLPATH
unzip -o $P1ZIP
mv $P1ZIP $DOWNLOADS
cd $MAINFLDR
unzip -o $P2ZIP
mv $P2ZIP $DOWNLOADS
cd $MAINFLDR
unzip -o $P3ZIP
mv $P3ZIP $DOWNLOADS
cd $INSTALLPATH
unzip -o $PATCH1ZIP
mv $PATCH1ZIP $DOWNLOADS

# Give the option to create a server startup script
processdisplay "CREATE STARTUP SCRIPT?"
inquire

if [ $PROCEED = "y" ]; then
read -p "Please enter your servers IP, and press [ENTER]: " MYIP
read -p "Please enter your servers PORT, and press [ENTER]: " MYPORT
read -p "Pease enter the max number of players you want to allow on your server, and press [ENTER]: " MAXP
read -p "Would you like to enable Punkbuster? ( 1=yes / 0=no ), then press [ENTER]: " MYPB


cat > $INSTALLPATH/startServer.sh << ZONE_CONF
#!/bin/bash
echo ""
echo "********************"
echo "*REMEMBER*" 
echo "'ctrl+a d' to detach screen."
echo "'screen -r' to reconnect to session."
echo "********************"
echo ""
cd $INSTALLPATH
screen wine CoDWaWmp.exe -- +set dedicated 2 +set net_ip $MYIP +set net_port $MYPORT +set ui_maxclients $MAXP +set sv_maxclients $MAXP +set sv_punkbuster $MYPB +exec server.cfg +map_rotate
exit 0
ZONE_CONF

chmod u+x $INSTALLPATH/startServer.sh

echo ""
echo "This script is now loated at: "
echo "$INSTALLPATH/startServer.sh"
echo ""
sleep 3

fi

if [ $PROCEED = "n" ]; then
	echo ""
	echo "Skipping startServer.sh creation..."
	echo "You will need to create your own startup command."
	echo ""
	sleep 3
fi


processdisplay "CREATE A SERVER.CFG?"
inquire

if [ $PROCEED = "y" ]; then
	echo "-- HOSTNAME --"
	echo "Valid colour codes are:"
	echo "^1 = Red"
	echo "^2 = Green"
	echo "^3 = Yellow"
	echo "^4 = Blue"
	echo "^5 = Cyan"
	echo "^6 = pink/Magenta"
	echo "^7 = White"
	echo "^0 = Black"
	echo ""
	echo "IE - ^1super^3Server"
	echo 
	read -p "Please enter your hostname, and press [ENTER]: " MYHOST
	echo ""
	echo ""	
	echo "-- ADMIN NAME --"
	read -p "Please enter the admin's name, and press [ENTER]: " MYADMIN
	echo ""
	echo ""	
	echo "-- ADMIN EMAIL --"
	read -p "Please enter the admin's email address, and press [ENTER]: " MYEMAIL
	echo ""
	echo ""	
	echo "-- WEBSITE --"
	read -p "Please enter your website URL, and press [ENTER]: " MYWEBSITE
	echo ""
	echo ""	
	echo "-- LOCATION --"
	echo "Please enter your Location, and press [ENTER]: "
	read -p "(IE - Canada) " MYLOC
	echo ""
	echo ""	
	echo "-- MESSAGE OF THE DAY --"
	read -p "Please enter your message of the day, and press [ENTER]: " MYMOTD
	echo ""
	echo ""	
	echo "-- PUNKBUSTER --"
	read -p "Would you like to enable Punkbuster? ( 1=yes / 0=no ), then press [ENTER]: " MYPB
	echo ""
	echo ""	
	echo "-- NUMBER OF PLAYERS --"
	read -p "Pease enter the max number of players you want to allow on your server, and press [ENTER]: " MAXP
fi

if [ $PROCEED = "n" ]; then
	processdisplay "You have chosen to skip entering your info. Assuming generic values. You will probably want to hand edit the server.cfg"
	declare -rx MYHOST="^0COD5-^1plus ^3Server"
	declare -rx MYADMIN=""
	declare -rx MYEMAIL=""
	delcare -rx MYWEBSITE=""
	declare -rx MYLOC=""
	declare -rx MYMOTD=""
	declare -rx MYPB="1"	
fi



# Create the new server.cfg file.
cat > $MAINFLDR/server.cfg << ZONE_CONF2
// Call of Duty World at War Server Configuration File
// Generated by COD5-Plus on $GENDATE

//************************************************** ****************************
// Color Codes
//************************************************** ****************************
// Colors for text. Do not clear the comment in front of the color codes.
// Useful for your server name, motd msg's - Information and ref use only
//
// ^1 = Red
// ^2 = Green
// ^3 = Yellow
// ^4 = Blue
// ^5 = Cyan
// ^6 = pink/Magenta
// ^7 = White
// ^0 = Black

//************************************************** ****************************
// Public Information
//************************************************** ****************************

sets sv_hostname "$MYHOST"
sets _Admin "$MYADMIN"
sets _Email "$MYEMAIL"
sets _Website "$MYWEBSITE"
sets _Location "$MYLOC"
sets _Irc ""
set scr_motd "$MYMOTD"

//************************************************** ****************************
// Common Server Settings
//************************************************** ****************************
// Log Settings
//************************************************** ****************************

set g_logsync "2" // 0=no log, 1=buffered, 2=continuous, 3=append
set logfile "1" // 0 = NO log, 1 = log file enabled
set g_log "games_mp.log" // Name of log file, default is games_mp.log
set sv_log_damage "1"

//************************************************** ****************************
// Password Settings
//************************************************** ****************************

set rcon_password "" // RCON must supply pw to use
set sv_privatePassword "" // Private slots, non-public slots

// The following can be used to lock out the server so that only those
// players that have been provide the password can connect. Good for
// matches, practices, etc.

set g_password ""

//************************************************** ****************************
// Player slots setup
//************************************************** ****************************

// Maximum Clients
set sv_maxclients "$MAXP"

// Number of private player slots, maxclients - privateclients = public slots
// These people can use the "sv_privatePassword" to get in the server.

set sv_privateclients ""

//************************************************** ****************************
// Ping
//************************************************** ****************************

// MIN player ping on CONNECT, any lower and player isnt allowed to connect

set sv_minPing "0" 

// MAX player ping on CONNECT, any higher and player isnt allowed to connect

set sv_maxping "350" 

//************************************************** ****************************
// Client Download Settings. 
//************************************************** ****************************

// (0=off/1=on) Used for MODs and custom maps

set sv_allowdownload "1"
seta sv_wwwDownload "1"

//seta sv_wwwBaseURL "http://www.your_website.com/base_folder"

seta sv_wwwDlDisconnected "1"

// Client's Maximum Download Rate
set sv_maxRate "25000"

//************************************************** ****************************
// Server Performance
//************************************************** ****************************

// FPS (Server Frames per Second) -- I would leave this alone for now.  MIGHT mess up gameplay if changed.
set sv_fps "20"

// Rate
set rate "25000"

// Antilag
set g_antilag "1"

// Smooth clients
set g_smoothClients "1"

//************************************************** ****************************
// Drop inactive players
//************************************************** ****************************

set sv_timeout "300"
set sv_zombietime "1"
set g_inactivity "0"
set g_inactivityspectator "0"

//************************************************** ****************************
// AntiFlooding Settings
//************************************************** ****************************

set sv_floodProtect "1"
set sv_reconnectlimit "3"

//************************************************** ****************************
// Anti Cheat Settings
//************************************************** ****************************

// Disable Client access to console?
set sv_disableClientConsole "0"
set cl_autocmd "0"
set sv_cheats "0"
set sv_pure "1"
set g_banIPs ""
set g_no_script_spam "1"
seta sv_punkbuster $MYPB
wait
pb_sv_enable

//************************************************** ****************************
// Temporary Ban duration, in seconds
//************************************************** ****************************

set sv_kickBanTime "300"

//************************************************** ****************************
// In-game communication system
//************************************************** ****************************

set sv_voice "0"
set sv_voiceQuality "1"
set voice_deadChat "0"
set voice_global "0"
set voice_localEcho "0"
set winvoice_mic_mute "1"

// Dead players chat with the living?

set g_deadChat "0"

//************************************************** ****************************
// Client
//************************************************** ****************************

// Client Voting
set g_allowVote "0"
set g_voteAbstainWeight "0.5"

// Client Side
set sv_clientside "0"
set sv_clientArchive "1"
set sv_clientSideBullets "1"
set sv_clientSideVehicles "1"
set g_client_side_lights "1"


//************************************************** ****************************
// Server Personality
//************************************************** ****************************

// Automatic Team Balance
set scr_teambalance "1"

// Who dead people can spectate
set scr_game_spectatetype "0"

// Gravity
set g_gravity "800"

// Base Move Speed
set g_speed "190"

// Number of dropped weapons before recycling
set g_maxDroppedWeapons "16"

// Red Crosshairs while over enemy? Maybe?
set g_redCrosshairs "0"

// Draw Friends
set scr_drawfriend "1"

//************************************************** ****************************
// Misc
//************************************************** ****************************

set sv_allowAnonymous "0"
set g_antilag "1"
set scr_xpscale "1"

//************************************************** ****************************
// Gameplay
//************************************************** ****************************

//Timers
set scr_game_graceperiod "25"
set scr_intermission_time "20"

//Kill Cam
set scr_game_allowkillcam "0"
set scr_game_onlyheadshots "0"
set scr_game_deathpointloss "0"
set scr_game_suicidepointloss "0"
set scr_team_teamkillpointloss "1"
set scr_game_spectatetype "1"
set scr_game_perks "1"
set scr_game_forceradar "0"
set scr_allowannouncer "1"
set scr_game_forceradar "0"
set scr_vehicles_enabled "1"
set vehControlMode "0"
set g_compassShowEnemies "0"
set g_allowvote "0"
// Revive players?  Don't know what this does
set scr_player_allowrevive "1"
set g_revive "0"
set revive_time_taken "2"

//************************************************** ****************************
// Weapons
//************************************************** ****************************

set scr_weapon_allowbetty "1"
set scr_weapon_allowc4 "1"
set scr_weapon_allowflash "1"
set scr_weapon_allowfrags "1"
set scr_weapon_allowmines "1"
set scr_weapon_allowrpgs "1"
set scr_weapon_allowsatchel "1"
set scr_weapon_allowsmoke "1"

// Bouncing Bettty Settings
set bettyDetonateRadius "150"
set bettyTimeBeforeDetonate "0.45"
set bettyUpVelocity "296"

// Poison gas stuff?
set poisonDuration "10"
set tabun_effect_radius "150"
set tabun_shock_radius "150"
set tabunGasDuration "3"
set tabunInitialGasShockDuration "7"
set tabunWalkInGasShockDuration "4"

// Fire
set fire_audio_random_max_duration "1000"
set fire_audio_repeat_duration "1500"
set fire_spread_probability "0"
set fire_stage1_burn_time "3000"
set fire_stage2_burn_time "0"
set fire_stage3_burn_time "0"
set fire_world_damage "20"
set fire_world_damage_duration "8"
set fire_world_damage_rate "0.25"

// Flares
set flare_distance_scale "16"
set flare_duration "8"
set flare_effect_radius "400"
set flareBurnOutFadeWait "0.65"
set flareDisableEffects "0"
set flareLookAwayFadeWait "0.45"

//************************************************** ****************************
// Batttle Chatter Settings
//************************************************** ****************************

set scr_allowbattlechatter "1"
set bcmp_incoming_grenade_probability "50"
set bcmp_kill_inform_probability "50"
set bcmp_killstreak_incoming_probability "50"
set bcmp_perk_call_probability "50"
set bcmp_sniper_kill_probability "25"
set bcmp_toss_grenade_probability "50"
set bcmp_weapon_delay "2000"
set bcmp_weapon_fire_probability "90"

//************************************************** ****************************
// Vehicles
//************************************************** ****************************

set scr_vehicles_enabled "1"
set scr_veh_respawntimemax "90"
set scr_veh_respawntimemin "50"
set scr_veh_health_jeep "700"
set scr_veh_health_tank "1350"
set scr_veh_driversarehidden "1"
set scr_veh_driversareinvulnerable "1"
set scr_veh_explode_on_cleanup "1"
set scr_veh_explosion_doradiusdamage "1"
set scr_veh_explosion_maxdamage "200"
set scr_veh_explosion_mindamage "20"
set scr_veh_explosion_radius "256"

set scr_veh_alive_cleanuptimemax "120"
set scr_veh_alive_cleanuptimemin "119"
set scr_veh_cleanupabandoned "1"
set scr_veh_cleanupdrifted "1"
set scr_veh_cleanupmaxspeedmph "1"
set scr_veh_cleanupmindistancefeet "75"
set scr_veh_cleanuptime_dmgfactor_deadtread "0.25"
set scr_veh_cleanuptime_dmgfactor_max "1.0"
set scr_veh_cleanuptime_dmgfactor_min "0.33"
set scr_veh_cleanuptime_dmgfraction_curve_begin "0.0"
set scr_veh_cleanuptime_dmgfraction_curve_end "1.0"
set scr_veh_dead_cleanuptimemax "30"
set scr_veh_dead_cleanuptimemin "20"
set scr_veh_disappear_maxpreventdistancefeet "30"
set scr_veh_disappear_maxpreventvisibilityfeet "150"
set scr_veh_disappear_maxwaittime "60"
set scr_veh_explosion_husk_forcepointvariance "30"
set scr_veh_explosion_husk_horzvelocityvariance "25"
set scr_veh_explosion_husk_vertvelocitymax "200"
set scr_veh_explosion_husk_vertvelocitymin "100"
set scr_veh_explosion_spawnfx "1"
set scr_veh_ondeath_createhusk "1"
set scr_veh_ondeath_usevehicleashusk "1"
set scr_veh_respawnafterhuskcleanup "1"
set scr_veh_respawnwait_iterationwaitseconds "1"
set scr_veh_respawnwait_maxiterations "30"
set scr_veh_waittillstoppedandmindist_maxtime "10"
set scr_veh_waittillstoppedandmindist_maxtimeenabledistfeet "5"

//************************************************** ****************************
// Hardpoints
//************************************************** ****************************

set scr_game_hardpoints "1"
set scr_hardpoint_allowartillery "1"
set scr_hardpoint_allowuav "1"
set scr_hardpoint_allowdogs "1"
set scr_hardpoint_allowradar "1"
set scr_hardpoint_allowsupply "1"

//************************************************** ****************************
// Teams
//************************************************** ****************************

// Friendly Fire?
set scr_team_fftype "0"
set scr_team_respawntime "0"
set scr_team_teamkillspawndelay "20"
set scr_team_kickteamkillers "0"
set scr_team_teamkillerplaylistbanquantum "0"
set scr_team_teamkillerplaylistbanpenalty "0"

//************************************************** ****************************
// player
//************************************************** ****************************

set scr_player_numlives "0"
set scr_player_maxhealth "100"
set scr_player_healthregentime "5"
//Sprint
set scr_player_sprinttime "5"

// Respawn Settings
set scr_player_forcerespawn "1"
set scr_player_respawndelay "0"
set scr_player_suicidespawndelay "20"

//************************************************** ****************************
// dogs
//************************************************** ****************************

set scr_dog_time "60"
set scr_dog_health "100"
set scr_dog_count "8"
set scr_dog_max_at_once "4"
set scr_dog_hardpoint_interval "180"

//************************************************** ****************************
// UI
//************************************************** ****************************

set scr_hardcore "0"
set scr_oldschool "0"
set ui_hud_hardcore "0"
set ui_hud_obituaries "1"
set ui_hud_showobjicons "1"

//************************************************** ****************************
// DEATHMATCH
//************************************************** ****************************

set scr_dm_scorelimit 150
set scr_dm_timelimit 10
set scr_dm_roundlimit 1
set scr_dm_numlives 0
set scr_dm_playerrespawndelay 0
set scr_dm_waverespawndelay 0
set scr_dm_globalbattlechatterprobability 100

//************************************************** ****************************
// DOMINATION
//************************************************** ****************************

set scr_dom_scorelimit 200
set scr_dom_timelimit 0
set scr_dom_roundlimit 1
set scr_dom_numlives 0
set scr_dom_playerrespawndelay 0
set scr_dom_waverespawndelay 0
set scr_dom_globalbattlechatterprobability 0

//************************************************** ****************************
// TEAM DEATHMATCH
//************************************************** ****************************

set scr_tdm_scorelimit 750
set scr_tdm_timelimit 10
set scr_tdm_roundlimit 1
set scr_tdm_numlives 0
set scr_tdm_playerrespawndelay 0
set scr_tdm_waverespawndelay 0
set scr_tdm_globalbattlechatterprobability 0

//************************************************** ****************************
// SABOTAGE
//************************************************** ****************************

set scr_sab_scorelimit 1
set scr_sab_timelimit 20
set scr_sab_roundlimit 0
set scr_sab_roundswitch 1
set scr_sab_numlives 0
set scr_sab_bombtimer 30
set scr_sab_planttime 2.5
set scr_sab_defusetime 5
set scr_sab_hotpotato 0
set scr_sab_playerrespawndelay 7.5
set scr_sab_waverespawndelay 0
set scr_sab_globalbattlechatterprobability 0

//************************************************** ****************************
// SEARCH AND DESTROY CLASSIC
//************************************************** ****************************

set scr_sd_scorelimit 4
set scr_sd_timelimit 2.5
set scr_sd_roundlimit 0
set scr_sd_roundswitch 3 // rounds between switching teams
set scr_sd_numlives 1 // elimination
set scr_sd_bombtimer 45
set scr_sd_planttime 5
set scr_sd_defusetime 5
set scr_sd_multibomb 0
set scr_sd_playerrespawndelay 0
set scr_sd_waverespawndelay 0
set scr_sd_globalbattlechatterprobability 0

//************************************************** ****************************
// CAPTURE THE FLAG
//************************************************** ****************************

set scr_ctf_scorelimit 3
set scr_ctf_timelimit 5
set scr_ctf_roundlimit 2
set scr_ctf_roundswitch 1
set scr_ctf_numlives 0
set scr_ctf_playerrespawndelay 0
set scr_ctf_waverespawndelay 15
set scr_ctf_touchreturn 1
set scr_ctf_idleflagreturntime 30
set scr_ctf_flagrespawntime 0
set scr_ctf_enemycarriervisible 0
set scr_ctf_globalbattlechatterprobability 0

//************************************************** ****************************
// KING OF THE HILL
//************************************************** ****************************

set scr_koth_scorelimit 250
set scr_koth_timelimit 15
set scr_koth_roundlimit 1
set scr_koth_roundswitch 1
set scr_koth_numlives 0
set scr_koth_playerrespawndelay 0
set scr_koth_waverespawndelay 0
set koth_autodestroytime 60
set koth_spawntime 0
set koth_kothmode 0
set koth_capturetime 20
set koth_destroytime 10
set koth_delayPlayer 0
set koth_spawnDelay 60
set scr_koth_globalbattlechatterprobability 0

//************************************************** ****************************
// WAR
//************************************************** ****************************

set scr_twar_timelimit 10
set twar_finalFightTimeLimit 5
set twar_captureTime 40
set twar_neutralFlagLockTime 0
set twar_captureAccelBonus 35
set twar_captureAccelLimit 50
set twar_momentumEnabled 1
set twar_momentumMax 70
set twar_momentumMaxMultiplier 3
set twar_momentumMultiplierBonus 25
set twar_momentumMultiplierBonusLimit 75
set twar_momentumBlitzkriegTime 30
set twar_momentumFlagCap 25
set twar_momentumKillPlayer 5
set twar_momentumRadar 10
set twar_momentumArtillery 10
set twar_momentumDogs 10
set twar_momentumKamikaze 10
set scr_twar_globalbattlechatterprobability 0

//************************************************** ****************************
// First gametype to load
// "dm" - free for all deathmatch
// "dom" - domination
// "koth" - headquarters
// "sab" - sabotage
// "sd" - search & destroy Classic
// "tdm" - team deathmatch
// "ctf" - capture the flag
// "twar" - NOT SURE YET
//************************************************** ****************************

//************************************************** ****************************
//MAP ROTATION SETTINGS - Uncomment the map line for the gametype you wish to play.
//************************************************** ****************************

//************************************************** ****************************
// DM -- FREE FOR ALL DEATHMATCH
//************************************************** ****************************

//set sv_mapRotation "gametype dm map mp_castle gametype dm map mp_makin gametype dm map mp_roundhouse"

//************************************************** ****************************
// DOM -- DOMINATION
//************************************************** ****************************

//set sv_mapRotation "gametype dom map mp_castle gametype dom map mp_makin gametype dom map mp_roundhouse"

//************************************************** ****************************
// KOTH -- HEADQUARTERS
//************************************************** ****************************

//set sv_mapRotation "gametype koth map mp_castle gametype koth map mp_makin gametype koth map mp_roundhouse"

//************************************************** ****************************
// SAB -- SABOTAGE
//************************************************** ****************************

//set sv_mapRotation "gametype sab map mp_castle gametype sab map mp_makin gametype sab map mp_roundhouse"

//************************************************** ****************************
// SD -- SEARCH & DESTROY CLASSIC
//************************************************** ****************************

//set sv_mapRotation "gametype sd map mp_castle gametype sd map mp_makin gametype sd map mp_roundhouse"

//************************************************** ****************************
// TDM -- TEAM DEATH MATCH
//************************************************** ****************************

//set sv_mapRotation "gametype tdm map mp_castle gametype tdm map mp_makin gametype tdm map mp_roundhouse"

//************************************************** ****************************
// CTF -- CAPTURE THE FLAG
//************************************************** ****************************

//set sv_mapRotation "gametype ctf map mp_castle gametype ctf map mp_makin gametype ctf map mp_roundhouse"

//************************************************** ****************************
// TWAR -- NOT SURE YET
//************************************************** ****************************

//set sv_mapRotation "gametype twar map mp_castle gametype twar map mp_makin gametype twar map mp_roundhouse"

//************************************************** ****************************
// CURRENT MAP ROTATION
//************************************************** ****************************

set sv_mapRotation "gametype tdm map mp_castle gametype tdm map mp_makin gametype tdm map mp_roundhouse" 
ZONE_CONF2

feedback "The server.cfg is located at: " "$MAINFLDR/server.cfg" "Feel free to edit, or use as is." "SCRIPT COMPLETE!"



processdisplay "INSTALL COMPLETE"
processdisplay "Copy your server.cfg into: $MAINFLDR (if you never generated one here)"
processdisplay "You can start the server with a command like (replace x's with your IP):"
processdisplay "cd $INSTALLPATH; screen wine CoDWaWmp.exe -- +set dedicated 2 +set net_ip xxx.xxx.xxx.xxx +set net_port 28960 +set ui_maxclients 18 +set sv_maxclients 18 +set sv_punkbuster 1 +exec server.cfg +map_rotate"
processdisplay "(If you did not generate one)".
processdisplay "INSTALL COMPLETE"
exit 0







